timeseries
==========

.. automodule:: timeseries

   
   
   .. rubric:: Functions

   .. autosummary::
   
      jagged
      wavy
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Signal
      SpaceCurve
   
   

   
   
   